/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.fritzmeier;

import java.awt.Image;
import java.io.IOException;
import java.util.logging.Logger;
import nl.cloudfarming.client.sensor.SensorDataObject;
import nl.cloudfarming.client.sensor.SensorFileNode;
import nl.cloudfarming.client.sensor.SensorProcessor;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.text.MultiViewEditorElement;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiFileLoader;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

public class FritzmeierDataObject extends SensorDataObject {

    public static final String MIME_TYPE = "text/csv-fritzmeier";
    public static final String ICON_BASE = "nl/cloudfarming/client/sensor/fritzmeier/fritzmeier-file-icon.png";
    private static final Logger LOG = Logger.getLogger("nl.cloudfarming.client.sensor.fritzmeier.FritzmeierDataObject");
    private FritzmeierFileProcessor processor = null;

    public FritzmeierDataObject(FileObject pf, MultiFileLoader loader) throws DataObjectExistsException, IOException {
        super(pf, loader);

        LOG.info("FritzmeierDataObject constructor");
        registerEditor(MIME_TYPE, true);
    }

    @Override
    protected int associateLookup() {
        return 1;
    }

    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.sensor.fritzmeier.about");
    }

    @MultiViewElement.Registration(displayName = "#LBL_Fritzmeier_EDITOR",
    iconBase = ICON_BASE,
    mimeType = MIME_TYPE,
    persistenceType = TopComponent.PERSISTENCE_ONLY_OPENED,
    preferredID = "Fritzmeier",
    position = 200)
    @Messages("LBL_Fritzmeier_EDITOR=Source")
    public static MultiViewEditorElement createEditor(Lookup lkp) {
        return new MultiViewEditorElement(lkp);
    }

    @Override
    protected Node createNodeDelegate() {
        return new FritzMeierNode(super.createNodeDelegate());
    }

    @Override
    protected SensorProcessor getProcessor() {
        if (processor == null) {
            processor = new FritzmeierFileProcessor(this);
        }
        return processor;
    }

    /**
     * Node for the FritzMeier
     */
    private class FritzMeierNode extends SensorFileNode {

        public FritzMeierNode(Node original) {
            super(original);
        }

        @Override
        public Image getIcon() {
            return ImageUtilities.loadImage(ICON_BASE);
        }
    }
}
